instrumenttools.ContrabassFlute
===============================

.. abjad-lineage:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute

.. autoclass:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute.ContrabassFlute.__repr__
   :noindex:
